@@ -40,6 +40,7 @@ impl Default for Binomial {
 }
 
 impl Distribution for Binomial {
+    type Output = f64;
     /// Samples from the given Binomial distribution. For `np <= 30`, this is done with an inversion algorithm.
     /// Otherwise, this is done with the BTPE algorithm from Kachitvichyanukul and Schmeiser 1988.
     fn sample(&self) -> f64 {
@@ -59,7 +60,9 @@ impl Distribution for Binomial {
 
         res as f64
     }
+}
 
+impl Distribution1D for Binomial {
     fn update(&mut self, params: &[f64]) {
         self.set_n(params[0] as u64);
         self.set_p(params[1]);
@@ -70,7 +73,7 @@ pub fn binomial_inversion(n: u64, p: f64) -> u64 {
     let s = p / (1. - p);
     let a = ((n + 1) as f64) * s;
     let mut r = (1. - p).powi(n as i32);
-    let mut u = fastrand::f64();
+    let mut u = alea::f64();
     let mut x: u64 = 0;
     while u > r as f64 {
         u -= r;
@@ -266,6 +269,7 @@ impl Discrete for Binomial {
 }
 
 impl Mean for Binomial {
+    type MeanType = f64;
     /// Calculates the mean, which is given by `np`.
     fn mean(&self) -> f64 {
         self.n as f64 * self.p
@@ -273,6 +277,7 @@ impl Mean for Binomial {
 }
 
 impl Variance for Binomial {
+    type VarianceType = f64;
     /// Calculates the variance, which is given by `npq`, where `q = 1-p`
     fn var(&self) -> f64 {
         self.n as f64 * self.p * (1. - self.p)
@@ -288,14 +293,14 @@ mod tests {
     #[test]
     fn test_moments() {
         let distr1 = Binomial::new(15, 0.3);
-        let data1 = distr1.sample_vec(1e6 as usize);
+        let data1 = distr1.sample_n(1e6 as usize);
         let mean1 = mean(&data1);
         let var1 = var(&data1);
         assert_approx_eq!(mean1, 4.5, 1e-2);
         assert_approx_eq!(var1, 3.15, 1e-2);
 
         let distr2 = Binomial::new(70, 0.5);
-        let data2 = distr2.sample_vec(1e6 as usize);
+        let data2 = distr2.sample_n(1e6 as usize);
         let mean2 = mean(&data2);
         let var2 = var(&data2);
         assert_approx_eq!(mean2, 35., 1e-2);
