@@ -7,4 +7,4 @@ pub use crate::predict::*;
 pub use crate::statistics::*;
 pub use crate::timeseries::*;
 pub use crate::validation::*;
-pub use autodiff::*;
+pub use reverse::*;
